==> kubernetes-model-1.0.60-sources.jar: io/fabric8/kubernetes/api/model/extensions/PetSetListFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.sundr.builder.annotations.Buildable;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.ListMeta;
import io.fabric8.kubernetes.api.model.ListMetaBuilder;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.ListMetaFluentImpl;
import java.lang.Object;
import lombok.ToString;

public class PetSetListFluentImpl<A extends PetSetListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements PetSetListFluent<A>{

    private String apiVersion;
    private List<VisitableBuilder<? extends PetSet,?>> items =  new ArrayList<VisitableBuilder<? extends PetSet,?>>();
    private String kind;
    private VisitableBuilder<? extends ListMeta,?> metadata;

    public PetSetListFluentImpl(){
    }
    public PetSetListFluentImpl(PetSetList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public A addToItems(PetSet... items){
            for (PetSet item : items) {PetSetBuilder builder = new PetSetBuilder(item);_visitables.add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(PetSet... items){
            for (PetSet item : items) {PetSetBuilder builder = new PetSetBuilder(item);_visitables.remove(builder);this.items.remove(builder);} return (A)this;
    }

    public List<PetSet> getItems(){
            return build(items);
    }

    public A withItems(List<PetSet> items){
            _visitables.removeAll(this.items);
            this.items.clear();
            if (items != null) {for (PetSet item : items){this.addToItems(item);}} return (A) this;
    }

    public A withItems(PetSet... items){
            this.items.clear(); if (items != null) {for (PetSet item :items){ this.addToItems(item);}} return (A) this;
    }

    public PetSetListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public PetSetListFluent.ItemsNested<A> addNewItemLike(PetSet item){
            return new ItemsNestedImpl(item);
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public ListMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ListMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new ListMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public PetSetListFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public PetSetListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item){
            return new MetadataNestedImpl(item);
    }

    public PetSetListFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public PetSetListFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ListMetaBuilder().build());
    }

    public PetSetListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    public A withNewMetadata(String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(resourceVersion, selfLink));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PetSetListFluentImpl that = (PetSetListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends PetSetFluentImpl<PetSetListFluent.ItemsNested<N>> implements PetSetListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final PetSetBuilder builder;
    
            ItemsNestedImpl(PetSet item){
                    this.builder = new PetSetBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.builder = new PetSetBuilder(this);
            }
    
    public N and(){
            return (N) PetSetListFluentImpl.this.addToItems(builder.build());
    }
    public N endItem(){
            return and();
    }

}
    public class MetadataNestedImpl<N> extends ListMetaFluentImpl<PetSetListFluent.MetadataNested<N>> implements PetSetListFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ListMetaBuilder builder;
    
            MetadataNestedImpl(ListMeta item){
                    this.builder = new ListMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ListMetaBuilder(this);
            }
    
    public N and(){
            return (N) PetSetListFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}


}

==> kubernetes-model-1.0.61-sources.jar: io/fabric8/kubernetes/api/model/extensions/PetSetListFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.String;
import javax.validation.constraints.NotNull;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.List;
import javax.validation.Valid;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Object;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ListMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ListMetaBuilder;

public class PetSetListFluentImpl<A extends PetSetListFluent<A>> extends BaseFluent<A> implements PetSetListFluent<A>{

    private String apiVersion;
    private List<VisitableBuilder<? extends PetSet,?>> items =  new ArrayList<VisitableBuilder<? extends PetSet,?>>();
    private String kind;
    private VisitableBuilder<? extends ListMeta,?> metadata;

    public PetSetListFluentImpl(){
    }
    public PetSetListFluentImpl(PetSetList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public A addToItems(PetSet... items){
            for (PetSet item : items) {PetSetBuilder builder = new PetSetBuilder(item);_visitables.add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(PetSet... items){
            for (PetSet item : items) {PetSetBuilder builder = new PetSetBuilder(item);_visitables.remove(builder);this.items.remove(builder);} return (A)this;
    }

    public List<PetSet> getItems(){
            return build(items);
    }

    public A withItems(List<PetSet> items){
            this.items.clear();
            if (items != null) {for (PetSet item : items){this.addToItems(item);}} return (A) this;
    }

    public A withItems(PetSet... items){
            this.items.clear(); if (items != null) {for (PetSet item :items){ this.addToItems(item);}} return (A) this;
    }

    public PetSetListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public PetSetListFluent.ItemsNested<A> addNewItemLike(PetSet item){
            return new ItemsNestedImpl(item);
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public ListMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ListMeta metadata){
            if (metadata!=null){ this.metadata= new ListMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public PetSetListFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public PetSetListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item){
            return new MetadataNestedImpl(item);
    }

    public PetSetListFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public A withNewMetadata(String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(resourceVersion, selfLink));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PetSetListFluentImpl that = (PetSetListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends PetSetFluentImpl<PetSetListFluent.ItemsNested<N>> implements PetSetListFluent.ItemsNested<N>,Nested<N>{

            private final PetSetBuilder builder;
    
            ItemsNestedImpl(){
                    this.builder = new PetSetBuilder(this);
            }
            ItemsNestedImpl(PetSet item){
                    this.builder = new PetSetBuilder(this, item);
            }
    
    public N endItem(){
            return and();
    }
    public N and(){
            return (N) PetSetListFluentImpl.this.addToItems(builder.build());
    }

}
    public class MetadataNestedImpl<N> extends ListMetaFluentImpl<PetSetListFluent.MetadataNested<N>> implements PetSetListFluent.MetadataNested<N>,Nested<N>{

            private final ListMetaBuilder builder;
    
            MetadataNestedImpl(){
                    this.builder = new ListMetaBuilder(this);
            }
            MetadataNestedImpl(ListMeta item){
                    this.builder = new ListMetaBuilder(this, item);
            }
    
    public N and(){
            return (N) PetSetListFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}


}
